==> nmds.1.2.tgz: MDS_final/mds.f <==
      program mds
c
      implicit none
c
      integer notus,notus1,nd,nd1,ntbnd
c
      parameter (notus=64,notus1=notus-1)
      parameter (nd=3,nd1=nd-1)
      parameter (ntbnd=notus*notus1/2)
c
      real cvchk,ds,rnseed,totrf
      integer ntop,idxnbd,idxrval
c
c if n < 100, ds =  1.0/notus**3
c if n = 300, ds = 0.1/notus**3      
      parameter (ds=0.1/notus**3)
      parameter (cvchk=5d-5)
      parameter (ntop=3000)
cc      parameter (rnseed=0.6751)
      parameter (rnseed=0.4619)
c      idxnbd,idxrval=0 : initialized.      
      parameter (idxrval=0,idxnbd=0)
c      
      real rval0(0:nd1,0:notus1),rval1(0:nd1,0:notus1)
      real dist(0:notus1,0:notus1)
      real dist2(0:notus1,0:notus1,0:1)
      real rbdwk(ntbnd),dr(0:nd1), rf(0:notus1,0:notus1)
c
      integer nbdwk(0:1,ntbnd),nbdsrt(0:1,ntbnd)
      integer nbdrnk(0:1,0:notus1,0:notus1)
      integer iperm(ntbnd)
      integer nbdwk2(notus1),nbdsrt2(notus1),nbdrnk2(0:1,notus1,0:1)
c
      real totdr
c      
      integer iotus,iotus0,iotus1,id,it,ibnd
      integer kflag,ier
c
      call init(idxrval,rnseed,rval1,notus1,nd1)
c
      if (idxnbd.eq.0) then
        call prep(dist,rbdwk,nbdwk,nbdsrt,nbdrnk,iperm,rval0,
     &  notus1,ntbnd,nd1)
        write(30) nbdrnk
        write(*,*) 'nbdrnk is generated and stored'
      else
        read(30) nbdrnk
        write(*,*) 'nbdrnk is loaded from stored file'
      end if  
c      
      do 100 it=1,ntop
c    renormalization
        call renorm(rval1,notus1,nd1)
c    substite into working array
        do 170 iotus=0,notus1
        do 170 id=0,nd1
          rval0(id,iotus)=rval1(id,iotus)
  170   continue
c   compute distance

        call distcal(rval1,dist,notus1,nd1)
c    sort distances
        ibnd=1
        do 180 iotus0=0,notus1
        do 180 iotus1=iotus0+1,notus1
          rbdwk(ibnd)=dist(iotus0,iotus1)
          nbdwk(0,ibnd)=iotus0
          nbdwk(1,ibnd)=iotus1
          ibnd=ibnd+1
c-----          
cc          write(*,*)'dist',iotus0,iotus1,dist(iotus0,iotus1)
c-----          
 180    continue
c
        kflag=1
        call spsort(rbdwk,ntbnd,iperm,kflag,ier)
c---
cc        write(*,*) (nbdwk(0,iperm(ibnd)),ibnd=1,ntbnd)
cc        write(*,*) (nbdwk(1,iperm(ibnd)),ibnd=1,ntbnd)
c---
c    Compure Force vector
        call fcal(rf,nbdrnk,nbdwk,iperm,ntbnd,notus1)
        totrf=0
        do 210 iotus0=0,notus1
          do 210 iotus1=iotus0+1,notus1
            totrf=totrf+abs(rf(iotus0,iotus1))
c----
cc            write(*,*) 'rf', iotus0,iotus1,rf(iotus0,iotus1),
cc     &        dist(iotus0,iotus1)
c----            
 210      continue
c    Compute position vector increment
        totdr=0
        do 190 iotus0=0,notus1
          do 140 id=0,nd1
            dr(id)=0.0d0
  140     continue  
c
c---
cc        write(*,*)iotus0, (rval1(id,iotus0),id=0,nd1)
c---
          do 150 iotus1=0,notus1
            do 150 id=0,nd1
              if (iotus0.ne.iotus1) then
            dr(id)=dr(id)
     &        - rf(iotus0,iotus1)*ds
     &        *(rval0(id,iotus1)-rval0(id,iotus0))
     &        /dist(iotus0,iotus1)
c---
cc            write(*,*) iotus1,id,dist(iotus0,iotus1),            
cc     &       - rf(iotus0,iotus1)*ds
cc     &        *(rval0(id,iotus1)-rval0(id,iotus0))
cc     &        /dist(iotus0,iotus1)            
c---
          end if
  150     continue
c    Move point due to computed increment
          do 160 id=0,nd1
            rval1(id,iotus0)=rval0(id,iotus0)+dr(id)
            totdr=totdr+dr(id)**2
  160     continue
  190   continue
        write(*,*) it,totrf,totdr**0.5/notus
c-----
cc        read(*,*)
c-----
c    Check conversion
        if (sqrt(totdr)/notus.lt.cvchk) then
          goto 200
         end if
c            
 100    continue
c
 200    continue
c
        write (*,*)
        write (*,*) 'Converged Configuration'
        do 220 iotus=0,notus1
          write (*,*) iotus, (rval1(id,iotus),id=0,nd1)
 220    continue
        write(*,*)
c          Confidence test1
        call test(dist2,rval1,rbdwk,nbdwk2,nbdsrt2,nbdrnk2,
     &    iperm,notus1,nd1)
c
        rewind(35)
        write(35,*) rval1
c
      stop
c
      end

==> nmds.1.2.3.tgz: MDS_final/mds.f <==
      program mds
c
      implicit none
c
      integer notus,notus1,nd,nd1,ntbnd
c
      parameter (notus=300,notus1=notus-1)
      parameter (nd=2,nd1=nd-1)
      parameter (ntbnd=notus*notus1/2)
c
      real cvchk,ds,rnseed,totrf
      integer ntop,idxnbd,idxrval
c
c if n < 100, ds =  1.0/notus**3
c if n = 300, ds = 0.1/notus**3      
      parameter (ds=0.1/notus**3)
      parameter (cvchk=5d-5)
      parameter (ntop=3000)
cc      parameter (rnseed=0.6751)
      parameter (rnseed=0.4619)
c      idxnbd,idxrval=0 : initialized.      
      parameter (idxrval=0,idxnbd=0)
c      
      real rval0(0:nd1,0:notus1),rval1(0:nd1,0:notus1)
      real dist(0:notus1,0:notus1)
      real dist2(0:notus1,0:notus1,0:1)
      real rbdwk(ntbnd),dr(0:nd1), rf(0:notus1,0:notus1)
      real avg(notus),obs(notus),dval(notus),dev(notus)
c
      integer nbdwk(0:1,ntbnd),nbdsrt(0:1,ntbnd)
      integer nbdrnk(0:1,0:notus1,0:notus1)
      integer iperm(ntbnd)
      integer nbdwk2(notus1),nbdsrt2(notus1),nbdrnk2(0:1,notus1,0:1)
c
      real totdr
c      
      integer iotus,iotus0,iotus1,id,it,ibnd
      integer kflag,ier
c
      call init(idxrval,rnseed,rval1,notus1,nd1)
c
      if (idxnbd.eq.0) then
        call prep(dist,rbdwk,nbdwk,nbdsrt,nbdrnk,iperm,rval0,
     &  notus1,ntbnd,nd1)
        write(30) nbdrnk
        write(*,*) 'nbdrnk is generated and stored'
      else
        read(30) nbdrnk
        write(*,*) 'nbdrnk is loaded from stored file'
      end if  
c      
      do 100 it=1,ntop
c    renormalization
        call renorm(rval1,notus1,nd1)
c    substite into working array
        do 170 iotus=0,notus1
        do 170 id=0,nd1
          rval0(id,iotus)=rval1(id,iotus)
  170   continue
c   compute distance

        call distcal(rval1,dist,notus1,nd1)
c    sort distances
        ibnd=1
        do 180 iotus0=0,notus1
        do 180 iotus1=iotus0+1,notus1
          rbdwk(ibnd)=dist(iotus0,iotus1)
          nbdwk(0,ibnd)=iotus0
          nbdwk(1,ibnd)=iotus1
          ibnd=ibnd+1
c-----          
cc          write(*,*)'dist',iotus0,iotus1,dist(iotus0,iotus1)
c-----          
 180    continue
c
        kflag=1
        call spsort(rbdwk,ntbnd,iperm,kflag,ier)
c---
cc        write(*,*) (nbdwk(0,iperm(ibnd)),ibnd=1,ntbnd)
cc        write(*,*) (nbdwk(1,iperm(ibnd)),ibnd=1,ntbnd)
c---
c    Compure Force vector
        call fcal(rf,nbdrnk,nbdwk,iperm,ntbnd,notus1)
        totrf=0
        do 210 iotus0=0,notus1
          do 210 iotus1=iotus0+1,notus1
            totrf=totrf+abs(rf(iotus0,iotus1))
c----
cc            write(*,*) 'rf', iotus0,iotus1,rf(iotus0,iotus1),
cc     &        dist(iotus0,iotus1)
cc            read(*,*)
c----            
 210      continue
c    Compute position vector increment
        totdr=0
        do 190 iotus0=0,notus1
          do 140 id=0,nd1
            dr(id)=0.0d0
  140     continue  
c
c---
cc          write(*,*)iotus0, (rval0(id,iotus0),id=0,nd1)
cc          read(*,*)
c---
          do 150 iotus1=0,notus1
            do 150 id=0,nd1
              if (iotus0.ne.iotus1) then
            dr(id)=dr(id)
     &        - rf(iotus0,iotus1)*ds
     &        *(rval0(id,iotus1)-rval0(id,iotus0))
     &        /dist(iotus0,iotus1)
c---
cc            write(*,*) iotus1,id,dist(iotus0,iotus1),
cc     &        rf(iotus0,iotus1),rval0(id,iotus0),rval0(id,iotus1),ds,
cc     &       - rf(iotus0,iotus1)*ds
cc     &        *(rval0(id,iotus1)-rval0(id,iotus0))
cc     &        /dist(iotus0,iotus1)
cc            read(*,*)
c---
          end if
  150     continue
c    Move point due to computed increment
          do 160 id=0,nd1
            rval1(id,iotus0)=rval0(id,iotus0)+dr(id)
            totdr=totdr+dr(id)**2
  160     continue
  190   continue
        write(*,*) it,totrf,totdr**0.5/notus
c-----
cc        read(*,*)
c-----
c    Check conversion
        if (sqrt(totdr)/notus.lt.cvchk) then
          goto 200
         end if
c            
 100    continue
c
 200    continue
c
        write (*,*)
        write (*,*) 'Converged Configuration'
        do 220 iotus=0,notus1
          write (*,*) iotus, (rval1(id,iotus),id=0,nd1)
 220    continue
        write(*,*)
c          Confidence test1
        call test(dist2,rval1,rbdwk,nbdwk2,nbdsrt2,nbdrnk2,
     &  avg,obs,dval,dev,iperm,notus,notus1,nd1)
c
        rewind(35)
        write(35,*) rval1
c
      stop
c
      end
